==> hamlib_1.2.13.orig.tar.gz: hamlib-1.2.13/kit/funcube.h <==
/*
 *  Hamlib KIT backend - FUNcube Dongle USB tuner description
 *  Copyright (c) 2009-2010 by Stephane Fillod
 *
 *  Derived from usbsoftrock-0.5:
 *  Copyright (C) 2009 Andrew Nilsson (andrew.nilsson@gmail.com)
 *
 *  Author: Stefano Speretta, Innovative Solutions In Space BV
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _FUNCUBE_H
#define _FUNCUBE_H 1

#define VID									0x04D8
#define PID									0xFB56
#define VENDOR_NAME							"Hanlincrest Ltd.         "
#define PRODUCT_NAME						"FunCube Dongle"

#define FUNCUBE_INTERFACE					0x02
#define FUNCUBE_CONFIGURATION				0x00
#define FUNCUBE_ALTERNATIVE_SETTING			0x00

#define INPUT_ENDPOINT						0x82
#define OUTPUT_ENDPOINT						0x02

// Commands
#define REQUEST_SET_FREQ					0x64
#define REQUEST_SET_FREQ_HZ					0x65
#define REQUEST_GET_FREQ_HZ					0x66
#define REQUEST_SET_LNA_GAIN				0x6E
#define REQUEST_GET_LNA_GAIN				0x96
#define REQUEST_GET_RSSI					0x68

#define FUNCUBE_SUCCESS						0x01

#endif	/* _FUNCUBE_H */

==> hamlib_1.2.14.orig.tar.gz: hamlib-1.2.14/kit/funcube.h <==
/*
 *  Hamlib KIT backend - FUNcube Dongle USB tuner description
 *  Copyright (c) 2009-2011 by Stephane Fillod
 *
 *  Derived from usbsoftrock-0.5:
 *  Copyright (C) 2009 Andrew Nilsson (andrew.nilsson@gmail.com)
 *
 *  Author: Stefano Speretta, Innovative Solutions In Space BV
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _FUNCUBE_H
#define _FUNCUBE_H 1

#define VID									0x04D8
#define PID									0xFB56
#define VENDOR_NAME							"Hanlincrest Ltd.         "
#define PRODUCT_NAME						"FunCube Dongle"

#define FUNCUBE_INTERFACE					0x02
#define FUNCUBE_CONFIGURATION				-1  /* no setup */
#define FUNCUBE_ALTERNATIVE_SETTING			0x00

#define INPUT_ENDPOINT						0x82
#define OUTPUT_ENDPOINT						0x02

// Commands
#define REQUEST_SET_FREQ					0x64
#define REQUEST_SET_FREQ_HZ					0x65
#define REQUEST_GET_FREQ_HZ					0x66
#define REQUEST_SET_LNA_GAIN				0x6E
#define REQUEST_GET_LNA_GAIN				0x96
#define REQUEST_GET_RSSI					0x68

#define FUNCUBE_SUCCESS						0x01

#endif	/* _FUNCUBE_H */
